@@ -1,7 +1,9 @@
 from time import time
+from typing import Union, Literal
 
 from platon import Web3
 from platon.datastructures import AttributeDict
+from platon_typing import HexStr, NodeID, BlockIdentifier
 
 from platon_aide.base.module import Module
 from platon_aide.utils import contract_transaction
@@ -22,7 +24,10 @@ def to_attribute_proposal(proposal):
 
 
 class Govern(Module):
-    governGasPrice: int = 2100000000000000
+    textGasPrice: int = 1500000000000000
+    versionGasPrice: int = 2100000000000000
+    paramGasPrice: int = 2000000000000000
+    cancelGasPrice: int = 3000000000000000
 
     def __init__(self, web3: Web3):
         super().__init__(web3)
@@ -30,23 +35,39 @@ class Govern(Module):
         self._result_type = 'event'
         self._get_node_info()
 
-    @property
-    def chain_version(self):
-        version = self.web3.pip.get_chain_version()
-        version_byte = int(version).to_bytes(length=3, byteorder='big')
+    def chain_version(self, version=None):
+        """ 获取链上的版本信息，或者转换指定的版本信息
+        支持以下形式：int: 66048, string: '1.2.0', list: [1, 2, 0]
+        """
+        version = version or self.web3.pip.get_chain_version()
+        version_bytes = None
+
+        if type(version) is int:
+            version_bytes = int(version).to_bytes(length=3, byteorder='big')
+
+        elif type(version) is list:
+            version_bytes = bytes(version)
+
+        elif type(version) is str:
+            vs = str(version).split('.')
+            version_bytes = bytes([int(v) for v in vs])
+
+        else:
+            ValueError('unrecognized version information')
+
         return ChainVersion({
-            'integer': version,
-            'major': version_byte[0],
-            'minor': version_byte[1],
-            'patch': version_byte[2],
+            'integer': int.from_bytes(version_bytes, 'big'),
+            'major': version_bytes[0],
+            'minor': version_bytes[1],
+            'patch': version_bytes[2],
         })
 
-    @contract_transaction()
+    @contract_transaction(default_txn={'gasPrice': versionGasPrice})
     def version_proposal(self,
-                         version,
-                         voting_rounds=4,
-                         pip_number=second(),
-                         node_id=None,
+                         version: int,
+                         voting_rounds: int = 4,
+                         pip_number: str = second(),
+                         node_id: Union[NodeID, HexStr] = None,
                          txn=None,
                          private_key=None,
                          ):
@@ -55,13 +76,13 @@ class Govern(Module):
         node_id = node_id or self._node_id
         return self.web3.pip.submit_version_proposal(node_id, pip_number, version, voting_rounds)
 
-    @contract_transaction()
+    @contract_transaction(default_txn={'gasPrice': paramGasPrice})
     def param_proposal(self,
-                       module,
-                       name,
-                       value,
-                       pip_number=second(),
-                       node_id=None,
+                       module: str,
+                       name: str,
+                       value: str,
+                       pip_number: str = second(),
+                       node_id: Union[NodeID, HexStr] = None,
                        txn=None,
                        private_key=None,
                        ):
@@ -70,12 +91,12 @@ class Govern(Module):
         node_id = node_id or self._node_id
         return self.web3.pip.submit_param_proposal(node_id, pip_number, module, name, value)
 
-    @contract_transaction()
+    @contract_transaction(default_txn={'gasPrice': cancelGasPrice})
     def cancel_proposal(self,
-                        proposal_id,
-                        voting_rounds=4,
-                        node_id=None,
-                        pip_number=second(),
+                        proposal_id: str,
+                        voting_rounds: int = 4,
+                        node_id: Union[NodeID, HexStr] = None,
+                        pip_number: str = second(),
                         txn=None,
                         private_key=None,
                         ):
@@ -84,10 +105,10 @@ class Govern(Module):
         node_id = node_id or self._node_id
         return self.web3.pip.submit_cancel_proposal(node_id, pip_number, voting_rounds, proposal_id)
 
-    @contract_transaction()
+    @contract_transaction(default_txn={'gasPrice': textGasPrice})
     def text_proposal(self,
-                      pip_number=second(),
-                      node_id=None,
+                      pip_number: str = second(),
+                      node_id: Union[NodeID, HexStr] = None,
                       txn=None,
                       private_key=None,
                       ):
@@ -98,11 +119,11 @@ class Govern(Module):
 
     @contract_transaction()
     def vote(self,
-             proposal_id,
-             option,
-             node_id=None,
-             version=None,
-             version_sign=None,
+             proposal_id: Union[bytes, HexStr],
+             option: int,
+             node_id: Union[NodeID, HexStr] = None,
+             version: int = None,
+             version_sign: Union[bytes, HexStr] = None,
              txn=None,
              private_key=None,
              ):
@@ -115,9 +136,9 @@ class Govern(Module):
 
     @contract_transaction()
     def declare_version(self,
-                        node_id=None,
-                        version=None,
-                        version_sign=None,
+                        node_id: Union[NodeID, HexStr] = None,
+                        version: int = None,
+                        version_sign: Union[bytes, HexStr] = None,
                         txn=None,
                         private_key=None,
                         ):
@@ -128,13 +149,31 @@ class Govern(Module):
         version_sign = version_sign or self._version_sign
         return self.web3.pip.declare_version(node_id, version, version_sign)
 
-    def get_proposal(self, proposal_id):
+    def get_proposal(self, proposal_id: Union[bytes, HexStr]):
         """ 获取提案信息
         """
         proposal = self.web3.pip.get_proposal(proposal_id)
         return to_attribute_proposal(proposal)
 
-    def get_proposal_result(self, proposal_id):
+    def get_active_proposal(self, proposal_type: Literal[2, 3] = None):
+        """ 获取提案信息
+        """
+        if proposal_type not in [2, 3]:
+            raise ValueError('unsupported proposal type')
+
+        block_number = self.web3.platon.block_number
+        proposal_list = self.proposal_list(proposal_type)
+
+        proposals = [proposal for proposal in proposal_list if proposal.EndVotingBlock > block_number]
+
+        if not proposals:
+            return None
+        if len(proposals) > 1:
+            raise ValueError('wrong proposal data')
+
+        return proposals[0]
+
+    def get_proposal_result(self, proposal_id: Union[bytes, HexStr]):
         """ 获取提案投票结果信息
         """
         proposal_result = self.web3.pip.get_proposal_result(proposal_id)
@@ -149,7 +188,10 @@ class Govern(Module):
 
         return ProposalResult(proposal_result)
 
-    def get_proposal_votes(self, proposal_id, block_identifier='latest'):
+    def get_proposal_votes(self,
+                           proposal_id: Union[bytes, HexStr],
+                           block_identifier: BlockIdentifier == 'latest'
+                           ):
         """ 获取提案实时投票信息
         """
         proposal_votes = self.web3.pip.get_proposal_votes(proposal_id, block_identifier)
@@ -167,21 +209,26 @@ class Govern(Module):
             'yeasRatio': proposal_votes[1] / partici_count if partici_count else 0,
         })
 
-    def proposal_list(self, proposal_type=None):
+    def proposal_list(self, proposal_type: Literal[1, 2, 3, 4] = None):
         """ 获取提案列表，可以根据提案类型过滤
         """
         proposal_list = self.web3.pip.proposal_list()
         if type(proposal_list) is not list:
             raise ValueError('proposals is not found.')
 
-        return [to_attribute_proposal(proposal) for proposal in proposal_list]
+        proposals = [to_attribute_proposal(proposal) for proposal in proposal_list]
+
+        if proposal_type:
+            return [proposal for proposal in proposals if proposal.ProposalType == proposal_type]
+
+        return proposals
 
     def get_govern_param(self, module, name):
         """ 获取可治理参数的值
         """
         return self.web3.pip.get_govern_param(module, name)
 
-    def govern_param_list(self, module=None):
+    def govern_param_list(self, module=''):
         """ 获取可治理参数列表信息
         """
         return self.web3.pip.govern_param_list(module)
